==> xmule_1.9.4b.orig.tar.gz: xmule-1.9.4b/src/ServerWnd.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#ifndef SERVERWND_H
#define SERVERWND_H

#include "ServerListCtrl.h"
//#include "afxwin.h"
//#include "ResizableLib/ResizableDialog.h"
//#include "HyperTextCtrl.h"
//#include "IconStatic.h"

// CServerWnd dialog

#include "wx/textctrl.h"
#include "wx/statbmp.h"
#include "wx/html/htmlwin.h"
#include "wx/dialog.h"

class CServerWnd : public wxPanel //CResizableDialog
{
  //DECLARE_DYNAMIC(CServerWnd)
  DECLARE_DYNAMIC_CLASS(CServerWnd)
    
    CServerWnd() {};

public:
	CServerWnd(wxWindow* pParent);   // standard constructor
	virtual ~CServerWnd();
	void Localize();
	void UpdateServerMetFromURL(wxString strURL);
	void UpdateMyInfo();

	//wxSizer* Create(wxWindow* parent);
// Dialog Data
	enum { IDD = IDD_SERVER };
	CServerListCtrl* serverlistctrl;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//virtual BOOL OnInitDialog();
	//DECLARE_MESSAGE_MAP()
public:
	//CHyperTextCtrl servermsgbox;
	wxHtmlWindow servermsgbox;
	wxTextCtrl logbox;
	void OnBnClickedAddserver(wxCommandEvent& evt);
	void OnBnClickedUpdateservermetfromurl(wxCommandEvent& evt);
	//afx_msg void OnBnClickedAddserver();
	//afx_msg void OnBnClickedUpdateservermetfromurl();
	void OnBnClickedResetLog(wxCommandEvent& evt);
private:
	wxStaticBitmap m_ctrlNewServerFrm;
	wxStaticBitmap m_ctrlUpdateServerFrm;

	DECLARE_EVENT_TABLE()
};
#endif

==> xmule_1.10.0b.orig.tar.gz: xmule-1.10.0b.orig/src/ServerWnd.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#ifndef SERVERWND_H
#define SERVERWND_H

#include "resource.h"                       // IDD_SERVER - audited 4 Nov 2004

#include <wx/panel.h>                      // wxPanel

class CServerListCtrl;

class CServerWnd: public wxPanel //CResizableDialog
{
  //DECLARE_DYNAMIC(CServerWnd)
  DECLARE_DYNAMIC_CLASS(CServerWnd)
    
    CServerWnd() {};

public:
	CServerWnd(wxWindow* pParent);   // standard constructor
	virtual ~CServerWnd();
	void Localize();
	void UpdateServerMetFromURL(wxString strURL);
	void UpdateMyInfo();

	//wxSizer* Create(wxWindow* parent);
// Dialog Data
	enum { IDD = IDD_SERVER };
	CServerListCtrl* serverlistctrl;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//virtual bool OnInitDialog();
	//DECLARE_MESSAGE_MAP()
public:
	//CHyperTextCtrl servermsgbox;
	void OnBnClickedAddserver(wxCommandEvent& evt);
	void OnBnClickedUpdateservermetfromurl(wxCommandEvent& evt);
	//afx_msg void OnBnClickedAddserver();
	//afx_msg void OnBnClickedUpdateservermetfromurl();
	void OnBnClickedResetLog(wxCommandEvent& evt);
private:
	DECLARE_EVENT_TABLE()
};
#endif
